#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/8/8 17:32
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
"""

2x08hnrb@yyu.hdernm.com----uc7jqzax----eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJHcm91cE5hbWUiOiJhYXZ5IHJ5ZGgiLCJVc2VyTmFtZSI6ImFhdnkgcnlkaCIsIkFjY291bnQiOiIiLCJTdWJqZWN0SUQiOiIxOTI0MzY5NjUwMjE3MzkwNDMyIiwiUGhvbmUiOiIiLCJHcm91cElEIjoiMTkyNDM2OTY1MDIwOTAwMTgyNCIsIlBhZ2VOYW1lIjoiIiwiTWFpbCI6IjJ4MDhobnJiQHl5dS5oZGVybm0uY29tIiwiQ3JlYXRlVGltZSI6IjIwMjUtMDUtMTkgMTY6MzY6MzMiLCJUb2tlblR5cGUiOjEsImlzcyI6Im1pbmltYXgifQ.ZQ_cSiErTQNHT37w8Ie2nIy4zLfmo0sBXbuIQd0uEU_HDyLn4WBrJ6O-CAnWldtxi9PY53YHZW6zTb33S9zDx4VcXVRO3Nxl5o2WQNYRj3KxxNtHWAGwtA-cCplmgY71m-Xe4kZtN-K25tgXVcWbdze4nev_OGdkDPHBxfhiP462P0wgQ_tqkl5BgTxgUhcskYNs6JogNQUP4c1LFoSR6vYoAYek95K199ehpBuE1jkLFa2JDzNlKlVq_e2LPZkwA7qW67Ih0yONFDEtvM5GXr9ZMjyFIhww4hIeYPGTpqwHnjY00GUzlh4F9e_gpsx-FLqxZn0Xfnhyz8YvUDidfQ

"""

from meutils.pipe import *
from meutils.caches import rcache
from meutils.db.redis_db import redis_aclient

from meutils.config_utils.lark_utils import get_next_token_for_polling
from meutils.apis.utils import make_request_httpx

base_url = "https://api.minimax.io/v1"
feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=oOK2uj"


@rcache(ttl=3600)
async def create_task(request: dict, api_key: Optional[str] = None):
    api_key = api_key or await get_next_token_for_polling(feishu_url)

    headers = {"Authorization": f"Bearer {api_key}"}
    path = "/video_generation"
    payload = request

    response = await make_request_httpx(
        base_url=base_url,
        headers=headers,

        path=path,
        payload=payload,
    )
    if task_id := response.get("task_id"):
        await redis_aclient.set(task_id, api_key, ex=7 * 24 * 3600)

    logger.debug(response)
    return response


@alru_cache(ttl=30)
async def get_task(task_id: str):
    token = await redis_aclient.get(task_id)  # 绑定对应的 token
    api_key = token and token.decode()

    headers = {"Authorization": f"Bearer {api_key}"}
    path = f"/query/video_generation?task_id={task_id}"

    response = await make_request_httpx(
        base_url=base_url,
        headers=headers,

        path=path
    )
    if file_id := response.get("file_id"):
        await redis_aclient.set(file_id, api_key, ex=7 * 24 * 3600)

    return response


@alru_cache(ttl=30)
async def get_file(file_id: str):
    token = await redis_aclient.get(file_id)  # 绑定对应的 token
    api_key = token and token.decode()

    headers = {"Authorization": f"Bearer {api_key}"}
    path = f"/files/retrieve?file_id={file_id}"

    response = await make_request_httpx(
        base_url=base_url,
        headers=headers,

        path=path
    )
    """
    {'file': {'file_id': 299393334087796,
  'bytes': 0,
  'created_at': 1754647084,
  'filename': 'output.mp4',
  'purpose': 'video_generation',
  'download_url': 'https://public-cdn-video-data-algeng.oss-cn-wulanchabu.aliyuncs.com/inference_output%2Fvideo%2F2025-08-08%2F5caadc3e-b812-4df2-8153-fa463d7ebab3%2Foutput.mp4?Expires=1754679844&OSSAccessKeyId=LTAI5tAmwsjSaaZVA6cEFAUu&Signature=%2FxSqhj1bI9MY%2FlS8SNrSJWphNTI%3D',
  'backup_download_url': 'https://public-cdn-video-data-algeng-us.oss-us-east-1.aliyuncs.com/inference_output%2Fvideo%2F2025-08-08%2F5caadc3e-b812-4df2-8153-fa463d7ebab3%2Foutput.mp4?Expires=1754679844&OSSAccessKeyId=LTAI5tCpJNKCf5EkQHSuL9xg&Signature=PPvLDVrhqzt%2FXi%2BaBvZRFAr1IEI%3D'},
 'base_resp': {'status_code': 0, 'status_msg': 'success'}}

    """
    return response


if __name__ == '__main__':
    data = {
        "model": "T2V-01",
        "prompt": "男子拿起一本书[上升]，然后阅读[固定]。",
        "duration": 6,
        "resolution": "1080P"
    }  # 299392563388531

    
    token = """eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJHcm91cE5hbWUiOiJhYXZ5IHJ5ZGgiLCJVc2VyTmFtZSI6ImFhdnkgcnlkaCIsIkFjY291bnQiOiIiLCJTdWJqZWN0SUQiOiIxOTI0MzY5NjUwMjE3MzkwNDMyIiwiUGhvbmUiOiIiLCJHcm91cElEIjoiMTkyNDM2OTY1MDIwOTAwMTgyNCIsIlBhZ2VOYW1lIjoiIiwiTWFpbCI6IjJ4MDhobnJiQHl5dS5oZGVybm0uY29tIiwiQ3JlYXRlVGltZSI6IjIwMjUtMDUtMTkgMTY6MzY6MzMiLCJUb2tlblR5cGUiOjEsImlzcyI6Im1pbmltYXgifQ.ZQ_cSiErTQNHT37w8Ie2nIy4zLfmo0sBXbuIQd0uEU_HDyLn4WBrJ6O-CAnWldtxi9PY53YHZW6zTb33S9zDx4VcXVRO3Nxl5o2WQNYRj3KxxNtHWAGwtA-cCplmgY71m-Xe4kZtN-K25tgXVcWbdze4nev_OGdkDPHBxfhiP462P0wgQ_tqkl5BgTxgUhcskYNs6JogNQUP4c1LFoSR6vYoAYek95K199ehpBuE1jkLFa2JDzNlKlVq_e2LPZkwA7qW67Ih0yONFDEtvM5GXr9ZMjyFIhww4hIeYPGTpqwHnjY00GUzlh4F9e_gpsx-FLqxZn0Xfnhyz8YvUDidfQ"""

    arun(
        create_task(data, api_key=token)
    )

    # arun(
    #     get_task('299392563388531')
    # )

    # arun(
    #     get_file('299393334087796')
    # )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : _test
# @Time         : 2024/1/9 08:58
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.serving.fastapi import App
from meutils.serving.fastapi.routers import scheduler

if __name__ == '__main__':
    app = App()
    scheduler.scheduler.add_job(lambda: print("hello"), 'interval', seconds=3)

    app.include_router(scheduler.router)
    app.run(port=8899)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : ppio_hailuo
# @Time         : 2025/7/30 09:02
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.decorators.retry import retrying
from meutils.apis.utils import make_request_httpx
from meutils.schemas.openai_types import TTSRequest
from meutils.config_utils.lark_utils import get_next_token_for_polling

from meutils.apis.ppio.videos import base_url, feishu_url


@retrying()
async def text_to_speech(request: TTSRequest, api_key: Optional[str] = None):
    """
    调用ppio接口创建语音
    :param request:
    :return:
    """
    if isinstance(api_key, str) and api_key.startswith("oneapi:"):
        api_key = api_key.removeprefix("oneapi:")

    api_key = api_key or await get_next_token_for_polling(feishu_url, from_redis=True, ttl=3600)  # todo: 优化

    headers = {
        "Authorization": f"Bearer {api_key}",
        "Content-Type": "application/json",
    }

    payload = request.model_dump(exclude_none=True)
    payload = {
        "text": request.input,
        "stream": False,
        "output_format": request.response_format if request.response_format in {"url", "hex"} else "hex",
        "voice_setting":
            {
                "speed": request.speed or 1,
                "voice_id": request.voice or "wumei_yujie",
                "emotion": "happy"
            },
        **payload
    }

    # logger.debug(bjson(payload))

    response = await make_request_httpx(
        base_url=base_url,
        path=request.model,
        payload=payload,

        headers=headers,

        debug=True
    )

    if request.response_format not in {"url", "hex"}:
        _ = bytes.fromhex(response["audio"])

        # logger.debug(type(_))

        return _

    return response


if __name__ == '__main__':
    data = {
        "model": "minimax-speech-02-turbo",
        "input": "你好",
        "voice": "柔美女友",
        "response_format": "url"
    }
    arun(
        text_to_speech(
            TTSRequest(
                model="minimax-speech-02-turbo",
                input="你好",

                # response_format='hex',

                # **data
            )
        ))

"""
curl \
-X POST https://api.ppinfra.com/v3/minimax-speech-02-turbo \
-H "Authorization: Bearer sk_3W5amR6wiLNSzAyz9wkHBxSf848ZQckbTzZQrxNY1Og" \
-H "Content-Type: application/json" \
-d '{
  "text": "近年来，人工智能在国内迎来高速发展期，技术创新与产业应用齐头并进。从基础的大模型研发到语音识别、图像处理、自然语言理解等关键技术突破，AI 正在深度赋能医疗、金融、制造、交通等多个领域。同时，政策支持和资本推动加速了技术落地，众多科技企业、创业团队和科研机构持续投入，形成了活跃的创新生态。AI 正逐步从实验室走向实际生产力，成为推动数字中国建设和经济高质量发展的重要引擎，未来发展潜力巨大。",
  "stream": false,
  "output_format": "url",
  "voice_setting": {
    "speed": 1.1,
    "voice_id": "male-qn-jingying",
    "emotion": "happy"
  }
}'

"""




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : mineru
# @Time         : 2025/1/23 13:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

import requests

token = """
eyJ0eXBlIjoiSldUIiwiYWxnIjoiSFM1MTIifQ.eyJqdGkiOiI4MDAwNDQ3NyIsInJvbCI6IlJPTEVfUkVHSVNURVIiLCJpc3MiOiJPcGVuWExhYiIsImlhdCI6MTczNzYxMTQ5MiwiY2xpZW50SWQiOiJsa3pkeDU3bnZ5MjJqa3BxOXgydyIsInBob25lIjoiIiwidXVpZCI6IjczNTZjNjY1LTU4MTMtNGQxNC04ZjFiLWM0NWIyZmFhYTBhMCIsImVtYWlsIjoiMzEzMzAzMzAzQHFxLmNvbSIsImV4cCI6MTczODgyMTA5Mn0.i8CwWoRE6j5wAC_hD9z9amkWT56HdOewgXMFV4jMpg17JHB0HOY-K4o9zp06Puav2vxkuC3Lnqm_8ip7-QdxsQ
"""
url = 'https://mineru.net/api/v4/extract/task'
header = {
    'Content-Type': 'application/json',
    "Authorization": f"Bearer {token.strip()}"
}
data = {
    'url': 'https://cdn-mineru.openxlab.org.cn/demo/example.pdf',
    'is_ocr': True,
    'enable_formula': False,
}

res = requests.post(url, headers=header, json=data)
print(res.status_code)
print(res.json())
print(res.json()["data"])

# {'task_id': 'adb223f6-794b-4950-8d60-d766ebd0bf14'}

task_id = 'adb223f6-794b-4950-8d60-d766ebd0bf14'
import requests

url = f'https://mineru.net/api/v4/extract/task/{task_id}'
header = {
    'Content-Type':'application/json',
    "Authorization": f"Bearer {token.strip()}"
}

res = requests.get(url, headers=header)
print(res.status_code)
print(res.json())
print(res.json()["data"])


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : adjusted_audio1
# @Time         : 2023/11/21 18:07
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from pydub import AudioSegment


def adjust_duration(audio1, audio2):
    # 加载音频文件
    audio1 = AudioSegment.from_file(audio1)
    audio2 = AudioSegment.from_file(audio2)

    # 获取两个音频文件的时长
    duration1 = len(audio1)
    duration2 = len(audio2)

    # 计算速度比率
    speed_ratio = duration1 / duration2
    print(speed_ratio)

    # 调整第二个音频的速度
    adjusted_audio2 = audio2.speedup(playback_speed=speed_ratio)

    return audio1, adjusted_audio2


if __name__ == '__main__':
    from pydub.playback import play

    # play(AudioSegment.from_file('10.wav'))

    # todo: 减速在报错

    adjusted_audio1, adjusted_audio2 = adjust_duration('1.wav', '10.wav')
    # 可以播放调整后的音频文件
    play(adjusted_audio1)
    play(adjusted_audio2)



import urllib.parse


def get_js_sha(t):
    from py_mini_racer import py_mini_racer

    # 创建JavaScript运行环境
    context = py_mini_racer.MiniRacer()
     
    # 定义一个JavaScript函数
    js_code = """

    function ff(e, t, n, r, o, i, a) {
        var u = e + (t & n | ~t & r) + (o >>> 0) + a;
        return (u << i | u >>> 32 - i) + t
    }

    function gg(e, t, n, r, o, i, a) {
        var u = e + (t & r | n & ~r) + (o >>> 0) + a;
        return (u << i | u >>> 32 - i) + t
    }

    function hh(e, t, n, r, o, i, a) {
        var u = e + (t ^ n ^ r) + (o >>> 0) + a;
        return (u << i | u >>> 32 - i) + t
    }

    function ii(e, t, n, r, o, i, a) {
        var u = e + (n ^ (t | ~r)) + (o >>> 0) + a;
        return (u << i | u >>> 32 - i) + t
    }


    function rotl(e, t) {
        return e << t | e >>> 32 - t
    }


    function rotr(e, t) {
        return e << 32 - t | e >>> t
    }


    function bytesToWords(e) {
        for (var t = [], n = 0, r = 0; n < e.length; n++, r += 8)
            t[r >>> 5] |= e[n] << 24 - r % 32;
        return t
    }

    function wordsToBytes(e) {
        for (var t = [], n = 0; n < 32 * e.length; n += 8)
            t.push(e[n >>> 5] >>> 24 - n % 32 & 255);
        return t
    }

    function bytesToHex(e) {
        for (var t = [], n = 0; n < e.length; n++)
            t.push((e[n] >>> 4).toString(16)),
            t.push((15 & e[n]).toString(16));
        return t.join("")
    }


    function endian(e) {
        if (e.constructor == Number)
            return 16711935 & rotl(e, 8) | 4278255360 & rotl(e, 24);
        for (var t = 0; t < e.length; t++)
            e[t] = endian(e[t]);
        return e
    }


    function stringToBytes(e) {
        var e = unescape(encodeURIComponent(e));
        for (var t = [], n = 0; n < e.length; n++)
            t.push(255 & e.charCodeAt(n));
        return t
    }


    function sha(t){
        var t = stringToBytes(t);
        for (var u = bytesToWords(t), c = 8 * t.length, s = 1732584193, l = -271733879, f = -1732584194, d = 271733878, h = 0; h < u.length; h++)
            u[h] = (u[h] << 8 | u[h] >>> 24) & 16711935 | (u[h] << 24 | u[h] >>> 8) & 4278255360;
        u[c >>> 5] |= 128 << c % 32,
        u[(c + 64 >>> 9 << 4) + 14] = c;
        for (var p = ff, v = gg, m = hh, g = ii, h = 0; h < u.length; h += 16) {
            var y = s
              , b = l
              , w = f
              , k = d;
            s = p(s, l, f, d, u[h + 0], 7, -680876936),
            d = p(d, s, l, f, u[h + 1], 12, -389564586),
            f = p(f, d, s, l, u[h + 2], 17, 606105819),
            l = p(l, f, d, s, u[h + 3], 22, -1044525330),
            s = p(s, l, f, d, u[h + 4], 7, -176418897),
            d = p(d, s, l, f, u[h + 5], 12, 1200080426),
            f = p(f, d, s, l, u[h + 6], 17, -1473231341),
            l = p(l, f, d, s, u[h + 7], 22, -45705983),
            s = p(s, l, f, d, u[h + 8], 7, 1770035416),
            d = p(d, s, l, f, u[h + 9], 12, -1958414417),
            f = p(f, d, s, l, u[h + 10], 17, -42063),
            l = p(l, f, d, s, u[h + 11], 22, -1990404162),
            s = p(s, l, f, d, u[h + 12], 7, 1804603682),
            d = p(d, s, l, f, u[h + 13], 12, -40341101),
            f = p(f, d, s, l, u[h + 14], 17, -1502002290),
            l = p(l, f, d, s, u[h + 15], 22, 1236535329),
            s = v(s, l, f, d, u[h + 1], 5, -165796510),
            d = v(d, s, l, f, u[h + 6], 9, -1069501632),
            f = v(f, d, s, l, u[h + 11], 14, 643717713),
            l = v(l, f, d, s, u[h + 0], 20, -373897302),
            s = v(s, l, f, d, u[h + 5], 5, -701558691),
            d = v(d, s, l, f, u[h + 10], 9, 38016083),
            f = v(f, d, s, l, u[h + 15], 14, -660478335),
            l = v(l, f, d, s, u[h + 4], 20, -405537848),
            s = v(s, l, f, d, u[h + 9], 5, 568446438),
            d = v(d, s, l, f, u[h + 14], 9, -1019803690),
            f = v(f, d, s, l, u[h + 3], 14, -187363961),
            l = v(l, f, d, s, u[h + 8], 20, 1163531501),
            s = v(s, l, f, d, u[h + 13], 5, -1444681467),
            d = v(d, s, l, f, u[h + 2], 9, -51403784),
            f = v(f, d, s, l, u[h + 7], 14, 1735328473),
            l = v(l, f, d, s, u[h + 12], 20, -1926607734),
            s = m(s, l, f, d, u[h + 5], 4, -378558),
            d = m(d, s, l, f, u[h + 8], 11, -2022574463),
            f = m(f, d, s, l, u[h + 11], 16, 1839030562),
            l = m(l, f, d, s, u[h + 14], 23, -35309556),
            s = m(s, l, f, d, u[h + 1], 4, -1530992060),
            d = m(d, s, l, f, u[h + 4], 11, 1272893353),
            f = m(f, d, s, l, u[h + 7], 16, -155497632),
            l = m(l, f, d, s, u[h + 10], 23, -1094730640),
            s = m(s, l, f, d, u[h + 13], 4, 681279174),
            d = m(d, s, l, f, u[h + 0], 11, -358537222),
            f = m(f, d, s, l, u[h + 3], 16, -722521979),
            l = m(l, f, d, s, u[h + 6], 23, 76029189),
            s = m(s, l, f, d, u[h + 9], 4, -640364487),
            d = m(d, s, l, f, u[h + 12], 11, -421815835),
            f = m(f, d, s, l, u[h + 15], 16, 530742520),
            l = m(l, f, d, s, u[h + 2], 23, -995338651),
            s = g(s, l, f, d, u[h + 0], 6, -198630844),
            d = g(d, s, l, f, u[h + 7], 10, 1126891415),
            f = g(f, d, s, l, u[h + 14], 15, -1416354905),
            l = g(l, f, d, s, u[h + 5], 21, -57434055),
            s = g(s, l, f, d, u[h + 12], 6, 1700485571),
            d = g(d, s, l, f, u[h + 3], 10, -1894986606),
            f = g(f, d, s, l, u[h + 10], 15, -1051523),
            l = g(l, f, d, s, u[h + 1], 21, -2054922799),
            s = g(s, l, f, d, u[h + 8], 6, 1873313359),
            d = g(d, s, l, f, u[h + 15], 10, -30611744),
            f = g(f, d, s, l, u[h + 6], 15, -1560198380),
            l = g(l, f, d, s, u[h + 13], 21, 1309151649),
            s = g(s, l, f, d, u[h + 4], 6, -145523070),
            d = g(d, s, l, f, u[h + 11], 10, -1120210379),
            f = g(f, d, s, l, u[h + 2], 15, 718787259),
            l = g(l, f, d, s, u[h + 9], 21, -343485551),
            s = s + y >>> 0,
            l = l + b >>> 0,
            f = f + w >>> 0,
            d = d + k >>> 0
        }
        return endian([s, l, f, d])
    }


    function exports(e) {
        var n = wordsToBytes(sha(e));
        return bytesToHex(n)
    }
    """
     
    # 执行JavaScript代码，这将在内部环境中编译和执行js_code
    context.eval(js_code)
     
    # 使用已定义的JavaScript函数
    result = context.call("exports", str(t))


     
    return result
from meutils.apis.hailuoai.yy import get_js_sha

print(get_js_sha("1729947920000"))
import json
import time
import subprocess
from urllib.parse import quote

TOKEN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM0MDY1MzUsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.mcozMacSciz0MORdleOMS_uhrixhIlpQmFmUwvn81I4"
USER_ID = "3de88ad0-8a38-48a9-8ed3-0d63f9c71296"
DEVICE_ID = "302833759512764417"


tt = "{}000".format(int(time.time()))
tt = "1730114652000"

url = "https://hailuoai.video/api/multimodal/generate/video?device_platform=web&app_id=3001&version_code=22201&uuid={}&device_id={}&os_name=Windows&browser_name=chrome&device_memory=8&cpu_core_num=20&browser_language=zh-CN&browser_platform=Win32&screen_width=2560&screen_height=1440&unix={}".format(USER_ID, DEVICE_ID, tt)


#
# params_dict = urllib.parse.parse_qs(url)
#
# # parse_qs 返回的字典中的值是列表
# # 如果想要去掉列表，可以使用字典推导式
# params_dict_cleaned = {k: v[0] for k, v in params_dict.items()}
#
# print(params_dict_cleaned)

# 原始URL字符串
original_url = url.split("hailuoai.video")[-1]

# 替换prompt
prompt = "smile"
payload = json.dumps({
    "desc": prompt,
    "useOriginPrompt": True,
    "fileList": []
}, ensure_ascii=False)
payload = payload.replace(" ", "")
un_prompt = prompt.replace(" ", "")
payload = payload.replace(un_prompt, prompt)
# 使用quote函数进行编码
encoded_url = quote(original_url)
original_url = encoded_url.replace("/", "%2F")

print(original_url)
yy_info = "{}_{}{}ooui".format(original_url, payload, get_js_sha(tt))
print(yy_info)

yy = get_js_sha(yy_info)
print(yy)


curl_cmd = [
    'curl',
    url,
    '-H', 'content-type: application/json',
    '-H',
    'token: {}'.format(TOKEN),
    '-H',
    'user-agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36',
    '-H', 'yy: {}'.format(yy),
    '--data-raw',
    payload
]
print(curl_cmd)
result = subprocess.run(curl_cmd, stdout=subprocess.PIPE, text=True)
res = result.stdout
print(res)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : r
# @Time         : 2024/9/2 14:39
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://swanhub.co/cunyue/person-modnet/demo
from meutils.pipe import *
from meutils.request_utils import create_request

from meutils.io.image import image_to_base64

from gradio_client import Client, handle_file

client = Client("gokaygokay/KolorsPlusPlus")
result = client.predict(
    image=None,
    text_prompt="一条狗",
    vlm_model_choice="Florence-2",
    use_enhancer=False,
    model_choice="Long",
    negative_prompt="",
    seed=0,
    randomize_seed=True,
    width=1024,
    height=1024,
    guidance_scale=5,
    num_inference_steps=20,
    num_images_per_prompt=1,
    api_name="/process_workflow"
)
print(result)

#
# from gradio_client import Client, handle_file
#
# client = Client("Kwai-Kolors/Kolors")
# result = client.predict(
#     prompt="画条狗",
#     ip_adapter_image=None,
#     ip_adapter_scale=0.5,
#     negative_prompt="",
#     seed=0,
#     randomize_seed=True,
#     width=1024,
#     height=1024,
#     guidance_scale=5,
#     num_inference_steps=25,
#     api_name="/infer"
# )
# print(result)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2025/3/3 16:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

import os

from aiocache.serializers import PickleSerializer
from aiocache import cached, Cache, RedisCache, caches

cache = memory_cache = cached

RedisCache.delete_all = lambda *args, **kwargs: caches.get(RedisCache).clear(*args, **kwargs)


def rcache(**kwargs):
    """serializer="pickle"

    noself: bool = False,
    key_builder=lambda *args, **kwargs: f"{args[1].seed} {args[1].prompt}"
    :param endpoint: str with the endpoint to connect to. Default is "127.0.0.1".
    :param port: int with the port to connect to. Default is 6379.
    :param db: int indicating database to use. Default is 0.
    :param password: str indicating password to use. Default is None.
    """
    if kwargs.get("serializer") == 'pickle':
        kwargs['serializer'] = PickleSerializer()

    connection_kwargs = {}
    if REDIS_URL := os.getenv("REDIS_URL"):
        user_password, base_url = REDIS_URL.split("@")
        endpoint, port = base_url.split(':')
        password = user_password.split(":")[-1]

        connection_kwargs['endpoint'] = endpoint
        connection_kwargs['port'] = port
        connection_kwargs['password'] = password

        # logger.debug(f"redis: {connection_kwargs}")

    return cached(
        cache=RedisCache,
        **connection_kwargs,

        **kwargs
    )


if __name__ == '__main__':
    from meutils.pipe import *


    @cache(ttl=10)
    async def fn(a):
        logger.debug("第一次")
        return a


    @cached(ttl=60)
    async def fn2(a):
        logger.debug("第一次")
        return a


    # @cache(ttl=3)
    @rcache(ttl=10)
    async def mfn(a):
        logger.debug("第一次")
        return a


    async def main(fn):
        for i in range(10):
            await fn(i)


    # arun(main(fn))
    # arun(main(fn2))

    arun(main(mfn))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : dist_utils
# @Time         : 2020/12/9 3:13 下午
# @Author       : yuanjie
# @Email        : meutils@qq.com
# @Software     : PyCharm https://github.com/yuanjie-ai/DNN/blob/master/8_NLP/0_utils/Levenshtein.md
# @Description  : 几何距离、编辑距离、语义距离等
"""

Levenshtein.distance(str1, str2) # 描述由一个字串转化成另一个字串最少的操作次数，在其中的操作包括插入、删除、替换。算法实现：动态规划
Levenshtein.hamming(str1, str2) # 要求str1和str2必须长度一致。是描述两个等长字串之间对应位置上不同字符的个数
Levenshtein.ratio(str1, str2) # r=(sum–ldist)/sum, sum=len(str1)+len(str2),ldist是类编辑距离。在类编辑距离中删除、插入依然+1，但是替换+2
Levenshtein.jaro(str1, str2) # Jaro Distance # 据说是用来判定健康记录上两个名字是否相同，也有说是是用于人口普查
Levenshtein.jaro_winkler(str1, str2) # 给予了起始部分就相同的字符串更高的分数

Levenshtein.seqratio(['newspaper', 'litter bin', 'tinny', 'antelope'], ['caribou', 'sausage', 'gorn', 'woody']) # like ratio()
Levenshtein.setratio(['newspaper', 'litter bin', 'tinny', 'antelope'], ['caribou', 'sausage', 'gorn', 'woody'])

"""

from sklearn.metrics.pairwise import cosine_similarity

# ME
from meutils.pipe import *


def jaccard(a, b):
    a, b = map(set, (a, b))
    return 1 - len(a & b) / len(a | b)


def get_sorted_top_k(array, top_k=1, axis=-1, reverse=False):  # 不准
    """https://blog.csdn.net/danengbinggan33/article/details/112525700
    多维数组排序
    Args:
        array: 多维数组
        top_k: 取数
        axis: 轴维度
        reverse: 是否倒序

    Returns:
        top_sorted_scores: 值
        top_sorted_indexes: 位置
    """
    if reverse:
        # argpartition分区排序，在给定轴上找到最小的值对应的idx，partition同理找对应的值
        # kth表示在前的较小值的个数，带来的问题是排序后的结果两个分区间是仍然是无序的
        # kth绝对值越小，分区排序效果越明显
        axis_length = array.shape[axis]
        partition_index = np.take(np.argpartition(array, kth=-top_k, axis=axis),
                                  range(axis_length - top_k, axis_length), axis)
    else:
        partition_index = np.take(np.argpartition(array, kth=top_k, axis=axis), range(0, top_k), axis)
    top_scores = np.take_along_axis(array, partition_index, axis)
    # 分区后重新排序
    sorted_index = np.argsort(top_scores, axis=axis)
    if reverse:
        sorted_index = np.flip(sorted_index, axis=axis)
    top_sorted_scores = np.take_along_axis(top_scores, sorted_index, axis)
    top_sorted_indexes = np.take_along_axis(partition_index, sorted_index, axis)
    return top_sorted_scores, top_sorted_indexes


# simhash https://blog.csdn.net/Trisyp/article/details/113623966

if __name__ == "__main__":
    import time
    from sklearn.metrics.pairwise import cosine_similarity

    x = np.random.rand(10, 128)
    y = np.random.rand(1000000, 128)

    start_time = time.time()
    z = cosine_similarity(x, y)
    sorted_index_1 = get_sorted_top_k(z, top_k=3, axis=1, reverse=True)[1]
    print(time.time() - start_time)

    start_time = time.time()
    z = cosine_similarity(x, y)
    sorted_index_2 = np.flip(np.argsort(z, axis=1)[:, -3:], axis=1)
    print(time.time() - start_time)

    print((sorted_index_1 == sorted_index_2).all())
    print(get_sorted_top_k(z, top_k=3, axis=1, reverse=True))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/1/15 15:45
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : fal-ai/xx 动态路由

from meutils.pipe import *
from meutils.db.redis_db import redis_aclient

from meutils.apis.fal.images import check

from meutils.schemas.task_types import TaskResponse
from meutils.schemas.video_types import VideoRequest

from meutils.schemas.fal_types import FEISHU_URL
from meutils.config_utils.lark_utils import get_next_token_for_polling

from fal_client import AsyncClient
from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks

# 平台/模型/版本
models_mapping = {
    "kling-video/v2/master/image-to-video": "latentsync",
    "kling-video/v2/master/text-to-video": "latentsync",
    "kling-video/lipsync/audio-to-video": "latentsync",  # todo
    "kling-video/lipsync/text-to-video": "latentsync",
}


async def create_task(model:str, request: dict, token: Optional[str] = None):
    """https://fal.ai/models/fal-ai/latentsync/api#queue-submit

    """
    token = token or await get_next_token_for_polling(feishu_url=FEISHU_URL, from_redis=True, check_token=check)
    logger.debug(request)

    application = f"fal-ai/{model.removeprefix('fal-ai/')}"  # fal-ai/flux-pro/kontext

    client = AsyncClient(key=token)
    response = await client.submit(
        application=application,
        arguments=request
    )
    request_id = response.request_id
    await redis_aclient.set(request_id, token, ex=7 * 24 * 3600)
    """
    {'cancel_url': 'https://queue.fal.run/fal-ai/flux-1/requests/db9b7555-efa8-495b-9be2-e6243e6406e6/cancel',
 'client': <httpx.AsyncClient object at 0x28d607fa0>,
 'request_id': 'db9b7555-efa8-495b-9be2-e6243e6406e6',
 'response_url': 'https://queue.fal.run/fal-ai/flux-1/requests/db9b7555-efa8-495b-9be2-e6243e6406e6',
 'status_url': 'https://queue.fal.run/fal-ai/flux-1/requests/db9b7555-efa8-495b-9be2-e6243e6406e6/status'}
 
 # AsyncRequestHandle(request_id='548a8736-eb56-492f-a788-c67432821919')

    """

    return {"request_id": request_id}


@alru_cache(ttl=5)
async def get_task(model:str, request_id: str):
    token = await redis_aclient.get(request_id)  # 绑定对应的 token
    token = token and token.decode()
    if not token:
        raise HTTPException(status_code=404, detail="TaskID not found")


    application = f"fal-ai/{model.removeprefix('fal-ai/')}"

    client = AsyncClient(key=token)
    response = await client.status(application, request_id, with_logs=True)

    logger.debug(response.__class__.__name__)  # Queued, InProgress, COMPLETED

    if metrics := response.__dict__.get("metrics"):  # {'inference_time': 17.29231595993042}
        response = await client.result(application, request_id)


    return response


if __name__ == '__main__':
    token = "cda184dc-4c6a-4776-be39-79bfd7771328:8c3f25093040ebd10afb93df6921e537"

    model = "fal-ai/flux-1/schnell"
    request = {
        "prompt": "Extreme close-up of a single tiger eye, direct frontal view. Detailed iris and pupil. Sharp focus on eye texture and color. Natural lighting to capture authentic eye shine and depth. The word \"FLUX\" is painted over it in big, white brush strokes with visible texture."
    }

    # r = arun(create_task(model, request, token))

    request_id = "548a8736-eb56-492f-a788-c67432821919"

    r = arun(get_task(model, request_id))
